package main

import (
	"log"
	"os"

	"clickandjoin.app/storageserver/modules/config"
	"clickandjoin.app/storageserver/modules/scylladb"
	"clickandjoin.app/storageserver/routers/router"
	"github.com/gofiber/fiber/v2"
	"github.com/gofiber/fiber/v2/middleware/cors"
	"github.com/gofiber/fiber/v2/middleware/logger"
	"github.com/sirupsen/logrus"
)

func init() {
	config.LoadConfig()

	if config.Cfg.Debug {
		logrus.SetLevel(logrus.DebugLevel)
	}

	logrus.Println("Debug:", config.Cfg.Debug)

	scylladb.InitDatabase()
}

func main() {
	app := fiber.New()

	app.Use(cors.New())

	if config.Cfg.Debug {
		app.Use(logger.New(logger.Config{
			Format: "${pid} ${locals:requestid} ${status} - ${method} ${path}​\n",
		}))
	}

	router.SetupRoutes(app)

	if len(os.Args) < 2 {
		log.Fatalln("Please specify port")
	}

	app.Listen("127.0.0.1:" + os.Args[1])
}
